"""
Content:
    # 企业微信webhook发送
Author:J.Hu
Date: 2021-07-23
"""
from requests import Session, Response
from typing import Optional
from enum import Enum

# webhook消息类型
class WebHookMsgType(str, Enum):
    TEXT = 'text'
    MD = 'markdown'
    IMG = 'image'
    NEWS = 'news'

# 基本
class BaseContent:
    def __init__(self, msgtype: WebHookMsgType, **kw):
        self._jsdata = {'msgtype': msgtype.value, msgtype.value: {}}
        datacontent = self._jsdata[msgtype.value]
        for k, v in kw.items():
            if v:
                datacontent[k] = v

    @property
    def jsdata(self) -> dict:
        return self._jsdata

    @jsdata.setter
    def jsdata(self, data):
        self._jsdata = data

# Text内容
class TextContent(BaseContent):
    def __init__(self, content, mentioned_list: Optional[list] = None, mentioned_mobile_list: Optional[list] = None):
        super().__init__(WebHookMsgType.TEXT, content=content,
                         mentioned_list=mentioned_list, mentioned_mobile_list=mentioned_mobile_list)

class Webhook:
    def __init__(self, url: str):
        self.url = url

    def send(self, content: Optional[TextContent]) -> Response:
        s = Session()
        rsp = s.post(self.url, json=content.jsdata)
        rsp.encoding = rsp.apparent_encoding
        return rsp

if __name__ == '__main__':
    pass
